# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

Name:		perl-Tie-IxHash
Version:	1.23
Release:	35.%{__distinit}%{__distvers}
Summary:	Ordered associative arrays for Perl
License:	GPL-1.0-or-later OR Artistic-1.0-Perl
URL:		https://metacpan.org/release/Tie-IxHash
Source0:	https://cpan.metacpan.org/modules/by-module/Tie/Tie-IxHash-%{version}.tar.gz
BuildArch:	noarch
# Module Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	make
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	perl(ExtUtils::MakeMaker)
BuildRequires:	sed
# Module Runtime
BuildRequires:	perl(integer)
BuildRequires:	perl(strict)
BuildRequires:	perl(Tie::Hash)
BuildRequires:	perl(vars)
# Test Suite
BuildRequires:	perl(Test::More)
# Optional Tests
BuildRequires:	perl(Test::Pod) >= 1.14
# Dependencies
%if 0%{?fedora} < 38 && 0%{?rhel} < 10
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
%endif

%description
This Perl module implements Perl hashes that preserve the order in
which the hash elements were added. The order is not affected when
values corresponding to existing keys in the IxHash are changed.
The elements can also be set to any arbitrary supplied order. The
familiar perl array operations can also be performed on the IxHash.

%prep
%setup -q -n Tie-IxHash-%{version}

# Fix line endings
sed -i -e 's/\r$//' Changes README

%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%install
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
%{_fixperms} -c %{buildroot}

%check
make test

%files
%doc Changes README
%{perl_vendorlib}/Tie/
%{_mandir}/man3/Tie::IxHash.3*

%changelog
* Thu Jun  8 2023 Paul Howarth <paul@city-fan.org> - 1.23-35
- Use SPDX-format license tag

* Sat Jun  1 2019 Paul Howarth <paul@city-fan.org> - 1.23-18
- Perl 5.30 rebuild

* Tue Apr  3 2018 Paul Howarth <paul@city-fan.org> - 1.23-13
- BR: perl-generators unconditionally
- BR: perl-interpreter rather than perl
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section

* Thu Oct 13 2016 Paul Howarth <paul@city-fan.org> - 1.23-7
- Classify buildreqs by usage
- Simplify find command using -delete

* Thu Aug 28 2014 Paul Howarth <paul@city-fan.org> - 1.23-2
- Drop %%defattr, redundant since rpm 4.4

* Sun Feb 24 2013 Paul Howarth <paul@city-fan.org> - 1.23-1
- Update to 1.23:
  - New method Clear()
  - Deleting current element when doing cycle using each will work (CPAN RT#82248)
- Drop upstreamed Makefile.PL patch

* Sun Jun 24 2012 Paul Howarth <paul@city-fan.org> - 1.22-8
- Don't need to remove empty directories from the buildroot
- Drop support for old distributions prior to FC-3:
  - Don't need to define %%{perl_vendorlib}
  - Use DESTDIR rather than PERL_INSTALL_ROOT

* Thu Jul  7 2011 Paul Howarth <paul@city-fan.org> - 1.22-4
- Rebuild for perl 5.14.1 in Rawhide
- Nobody else likes macros for commands
- Fix dist tag for CentOS 6 and Scientific Linux

* Thu Jun 24 2010 Paul Howarth <paul@city-fan.org> - 1.22-3
- Rebuild for perl 5.12.1 in Rawhide

* Thu May 27 2010 Paul Howarth <paul@city-fan.org> - 1.22-2
- Fix dist tag for RHEL-6 Beta

* Wed Mar  3 2010 Paul Howarth <paul@city-fan.org> - 1.22-1
- Import from Fedora
- Update to 1.22 (modernize distribution)
- BR: perl(Test::More), perl(Test::Pod)
- Fix Makefile.PL to work with old ExtUtils::MakeMaker versions

* Fri Dec  4 2009 Stepan Kasal <skasal@redhat.com> - 1.21-11
- Rebuild against perl 5.10.1

* Sun Jul 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.21-10
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Thu Feb 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.21-9
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Wed Feb 27 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 1.21-8
- Rebuild for perl 5.10 (again)

* Mon Jan 28 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 1.21-7
- Rebuild for new perl

* Wed Oct 17 2007 Tom "spot" Callaway <tcallawa@redhat.com> - 1.21-6.1
- Correct license tag
- Add BR: perl(ExtUtils::MakeMaker)

* Thu Sep  7 2006 Jose Pedro Oliveira <jpo at di.uminho.pt> - 1.21-6
- Rebuild for FC6

* Thu Feb 16 2006 Jose Pedro Oliveira <jpo at di.uminho.pt> - 1.21-5
- Rebuild for FC5 (perl 5.8.8)

* Thu Dec 29 2005 Jose Pedro Oliveira <jpo at di.uminho.pt> - 1.21-4
- Dist tag

* Wed Apr  6 2005 Michael Schwendt <mschwendt[AT]users.sf.net> - 1.21-3
- Rebuilt

* Sun May  9 2004 Jose Pedro Oliveira <jpo at di.uminho.pt> - 0:1.21-0.fdr.2
- Avoid creation of the perllocal.pod file (make pure_install)

* Thu May  6 2004 Jose Pedro Oliveira <jpo at di.uminho.pt> - 0:1.21-0.fdr.1
- First build
